import 'package:cpt_community/components/comments_dialog.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/my_text_view.dart';

// 'id':1,
// 'avator': Assets.communityCamera,
// 'title': 'William Jefferson',
// 'isFollow': false,
// 'content': 'She said YES and our lives changed.Thank you all for coming to my propose today.We hope everyone can ……[More]',
// 'imageUrls': ['https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500','https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500','https://img2.baidu.com/it/u=3489233687,2364672159&fm=253&fmt=auto&app=120&f=JPEG?w=507&h=500'],
// 'time': 'June 17,2016 at 7:23 p.m.',
// 'likeno': 12

class NewsFeedCardContent extends StatelessWidget {
  final String content;
  final List? imageUrls;
  int? rowMaxImageNum=3;
  int? textMaxLines = 3;
  NewsFeedCardContent({
    Key? key,
    required this.content,
    this.imageUrls,
    this.rowMaxImageNum = 3,
    this.textMaxLines = 3
  }) : super(key: key);


  @override
  Widget build(BuildContext context) {
    List imageUrlsList = [];
    if(imageUrls != null && imageUrls!.isNotEmpty){
      // dart 取出 imageUrls 里面的前三张图片
      imageUrlsList = imageUrls!.take(rowMaxImageNum!).toList();
    }
    int totalImageCount = imageUrls!.length;
    int otherImageCount = imageUrls!.length - rowMaxImageNum!;
    int rowActualImageCount = imageUrls!.length > rowMaxImageNum! ? rowMaxImageNum! : imageUrls!.length;
    return LayoutBuilder(
        builder: (BuildContext context, BoxConstraints constraints) {
          final maxHeight = constraints.maxHeight;
          final minHeight = constraints.minHeight;
          final maxWidth = constraints.maxWidth;
          Log.d("---maxHeight-----$maxHeight-- $minHeight  $maxWidth--");
          return Container(
            width: double.infinity,
            padding: const EdgeInsets.symmetric(horizontal: 15),
            child: Column(
                children: [
                  MyTextView(
                    content,
                    textColor: context.appColors.textBlack,
                    fontSize: 15,
                    maxLines: textMaxLines,
                    isTextEllipsis: true,
                  ),
                  const SizedBox(height: 12),
                  // 图片
                  _buildImageSection(context,maxWidth - 15, imageUrlsList, totalImageCount,otherImageCount),
                ]
            )
          );
      }
    );
  }


  Widget _buildImageSection(BuildContext context,double maxWidth, List? imageUrls, int totalImageCount, int otherImageCount) {
    if (imageUrls != null && imageUrls!.isNotEmpty) {
      final imageCount = imageUrls.length;
      return SizedBox(
        width: maxWidth,
        height: 87,
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: List.generate(
              imageUrls.length,
              (index) => Container(
                height: 87,
                width: maxWidth/imageCount - 16 * (imageCount-1),
                margin: EdgeInsets.only(right: (index!=imageCount-1) ? 16 : 0 ),
                color: ColorUtils.string2Color("#F2F3F6"),
                // color: Colors.red,
                child:Stack(
                    children: [
                      MyLoadImage(
                        imageUrls[index],
                        width: maxWidth/imageCount - (16 * imageCount-1),
                        height: 87,
                        fit: BoxFit.cover,
                        cornerRadius: 5,
                      ),
                      otherImageCount > 0 && index == imageCount-1 ?
                        Positioned(
                        bottom: 0,
                        right: 0,
                        child: Container(
                          padding: const EdgeInsets.symmetric(horizontal: 5, vertical: 2),
                          color: context.appColors.textBlack.withOpacity(0.5),
                          child: MyTextView(
                            "+$otherImageCount",
                            textColor: Colors.white,
                            fontSize: 12,
                          ),
                        ),
                      ): const SizedBox.shrink(),
                    ]
                  )
              ),
          )
        )
            );
      } else {
        return const SizedBox.shrink();
      }
    }
}